@@ -116,8 +116,7 @@ class Sms:
         password = settings.SKEBBY_PASSWORD
 
         method = self._check_method(method)
-        template = get_template_from_string(self.text)
-        text = smart_str(template.render(Context(ctx)))
+        self.text = smart_str(self.template.render(Context(ctx)))
 
         payload = {
             'recipients': recipient,
@@ -132,7 +131,7 @@ class Sms:
         r = requests.post(SKEBBY_URL, data=payload, headers=self.headers)
         return _parse_response(r)
 
-def credit_left():
+def skebby_credit_left():
 
     username = settings.SKEBBY_USERNAME
     password = settings.SKEBBY_PASSWORD
